@@ -79,6 +79,7 @@ using namespace simd;
 #endif // SIMDUTF_FEATURE_UTF32
 #if SIMDUTF_FEATURE_BASE64
   #include "icelake/icelake_base64.inl.cpp"
+  #include "icelake/icelake_find.inl.cpp"
 #endif // SIMDUTF_FEATURE_BASE64
 
 #include <cstdint>
@@ -1729,6 +1730,16 @@ size_t implementation::binary_to_base64(const char *input, size_t length,
     return encode_base64<false>(output, input, length, options);
   }
 }
+
+const char *implementation::find(const char *start, const char *end,
+                                 char character) const noexcept {
+  return util_find(start, end, character);
+}
+const char16_t *implementation::find(const char16_t *start, const char16_t *end,
+                                     char16_t character) const noexcept {
+  return util_find(start, end, character);
+}
+
 #endif // SIMDUTF_FEATURE_BASE64
 
 } // namespace SIMDUTF_IMPLEMENTATION
