@@ -138,6 +138,7 @@ must_be_2_3_continuation(const simd8<uint8_t> prev2,
 
 #if SIMDUTF_FEATURE_BASE64
   #include "generic/base64.h"
+  #include "generic/find.h"
 #endif // SIMDUTF_FEATURE_BASE64
 
 //
@@ -1392,6 +1393,16 @@ size_t implementation::binary_to_base64(const char *input, size_t length,
     return encode_base64<false>(output, input, length, options);
   }
 }
+
+const char *implementation::find(const char *start, const char *end,
+                                 char character) const noexcept {
+  return util::find(start, end, character);
+}
+
+const char16_t *implementation::find(const char16_t *start, const char16_t *end,
+                                     char16_t character) const noexcept {
+  return util::find(start, end, character);
+}
 #endif // SIMDUTF_FEATURE_BASE64
 
 } // namespace SIMDUTF_IMPLEMENTATION
