@@ -11,7 +11,9 @@
 #include <tests/helpers/random_utf8.h>
 
 namespace {
-std::array<size_t, 9> input_size{7, 12, 16, 64, 67, 128, 256, 511, 1000};
+constexpr std::array<size_t, 9> input_size{7,   12,  16,  64,  67,
+                                           128, 256, 511, 1000};
+constexpr simdutf::endianness LE = simdutf::endianness::LITTLE;
 
 using simdutf::tests::helpers::transcode_utf8_to_utf16_test_base;
 
@@ -280,7 +282,6 @@ TEST(issue_456) {
 }
 
 TEST(convert_check_validation) {
-  fflush(NULL);
   uint32_t seed{1234};
   simdutf::tests::helpers::random_utf8 gen_1_2_3_4(seed, 1, 1, 1, 1);
   size_t total = 1000;
@@ -420,7 +421,7 @@ TEST_LOOP(trials, convert_pure_ASCII) {
   };
 
   for (size_t size : input_size) {
-    transcode_utf8_to_utf16_test_base test(generator, size);
+    transcode_utf8_to_utf16_test_base test(LE, generator, size);
     ASSERT_TRUE(test(procedure));
     ASSERT_TRUE(test.check_size(size_procedure));
   }
@@ -439,7 +440,7 @@ TEST_LOOP(trials, convert_1_or_2_UTF8_bytes) {
     return implementation.utf16_length_from_utf8(utf8, size);
   };
   for (size_t size : input_size) {
-    transcode_utf8_to_utf16_test_base test(random, size);
+    transcode_utf8_to_utf16_test_base test(LE, random, size);
     ASSERT_TRUE(test(procedure));
     ASSERT_TRUE(test.check_size(size_procedure));
   }
@@ -459,7 +460,7 @@ TEST_LOOP(trials, convert_1_or_2_or_3_UTF8_bytes) {
     return implementation.utf16_length_from_utf8(utf8, size);
   };
   for (size_t size : input_size) {
-    transcode_utf8_to_utf16_test_base test(random, size);
+    transcode_utf8_to_utf16_test_base test(LE, random, size);
     ASSERT_TRUE(test(procedure));
     ASSERT_TRUE(test.check_size(size_procedure));
   }
@@ -478,7 +479,7 @@ TEST_LOOP(trials, convert_2_UTF8_bytes) {
     return implementation.utf16_length_from_utf8(utf8, size);
   };
   for (size_t size : input_size) {
-    transcode_utf8_to_utf16_test_base test(random, size);
+    transcode_utf8_to_utf16_test_base test(LE, random, size);
     ASSERT_TRUE(test(procedure));
     ASSERT_TRUE(test.check_size(size_procedure));
   }
@@ -497,7 +498,7 @@ TEST_LOOP(trials, convert_3_UTF8_bytes) {
     return implementation.utf16_length_from_utf8(utf8, size);
   };
   for (size_t size : input_size) {
-    transcode_utf8_to_utf16_test_base test(random, size);
+    transcode_utf8_to_utf16_test_base test(LE, random, size);
     ASSERT_TRUE(test(procedure));
     ASSERT_TRUE(test.check_size(size_procedure));
   }
@@ -517,7 +518,7 @@ TEST_LOOP(trials, convert_3_or_4_UTF8_bytes) {
     return implementation.utf16_length_from_utf8(utf8, size);
   };
   for (size_t size : input_size) {
-    transcode_utf8_to_utf16_test_base test(random, size);
+    transcode_utf8_to_utf16_test_base test(LE, random, size);
     ASSERT_TRUE(test(procedure));
     ASSERT_TRUE(test.check_size(size_procedure));
   }
@@ -534,21 +535,20 @@ TEST_LOOP(trials, convert_null_4_UTF8_bytes) {
   };
 
   for (size_t size : input_size) {
-    transcode_utf8_to_utf16_test_base test(random, size);
+    transcode_utf8_to_utf16_test_base test(LE, random, size);
     ASSERT_TRUE(test(procedure));
   }
 }
 
-#if SIMDUTF_IS_BIG_ENDIAN
-// todo: port this test for big-endian platforms.
-#else
 TEST(issue111) {
   // We stick to ASCII for our source code given that there is no universal way
   // to specify the character encoding of the source files.
   char16_t input[] =
       u"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa\u30b3aa"
       u"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa";
-  size_t utf16_len = sizeof(input) / sizeof(char16_t) - 1;
+  const size_t utf16_len = sizeof(input) / sizeof(char16_t);
+  to_utf16le_inplace(input, utf16_len);
+
   ASSERT_TRUE(implementation.validate_utf16le(input, utf16_len));
   ASSERT_EQUAL(implementation.utf8_length_from_utf16le(input, utf16_len),
                2 + utf16_len);
@@ -567,7 +567,6 @@ TEST(issue111) {
       std::char_traits<char16_t>::compare(input, utf16_buffer.get(), utf16_len),
       0);
 }
-#endif
 
 TEST(special_cases) {
   const uint8_t utf8[] = {0xC2, 0xA9};     // copyright sign
